@@ -2,30 +2,11 @@ import asyncio
 from datetime import date, datetime
 from typing import Any
 from .base import AsyncBaseAPI
-from .utils import AsyncAPIUtils
 from .. import types
 
 class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
     """Основной Async класс почти со всеми функциями API.\n~~~"""
     
-    def __init__(self, login: str = None, password: str = None, token: str = None, get_info: bool = False) -> None:
-        super().__init__(login, password, token)
-        self.utils = AsyncAPIUtils(self)
-
-        if get_info:
-            try:
-                self.me_context = asyncio.get_event_loop().run_until_complete(self.get_context())
-                self.me_user = asyncio.get_event_loop().run_until_complete(self.get_user())
-                self.me_person = asyncio.get_event_loop().run_until_complete(self.get_person())
-            except:
-                self.me_context = None
-                self.me_user = None
-                self.me_person = None
-        else:
-            self.me_context = None
-            self.me_user = None
-            self.me_person = None
-    
     async def check_person(self, value):
         if value == "me":
             return (self.me_context).personId if self.me_context else (await self.get_user()).personId
