@@ -9,14 +9,14 @@ class Lesson(Type):
     """Урок"""
     
     id: int
-    id_str: str = None
-    title: str = None
-    date: datetime = None
-    number: int = None
+    id_str: str | None = None
+    title: str | None = None
+    date: datetime | None = None
+    number: int | None = None
     subject: Subject
     group: int
-    status: str = None
-    resultPlaceId: int = None
+    status: str | None = None
+    resultPlaceId: int | None = None
     works: list[Work] = []
     teachers: list[int] = []
     teachers_str: list[str] = []
