@@ -4,21 +4,21 @@ from .model import Type
 class School(Type):
     """[GET] /v2.0/schools/{school}\n~~~\nПрофиль школы\n~~~"""
     
-    fullName: str = None
-    avatarSmall: str = None
-    city: str = None
-    municipality: str = None
-    regionid: int = None
-    markType: str = None
-    timeZone: int = None
-    uses_avg: bool = None
-    uses_weighted_avg: bool = None
-    id: int = None
-    id_str: str = None
+    fullName: str | None = None
+    avatarSmall: str | None = None
+    city: str | None = None
+    municipality: str | None = None
+    regionid: int | None = None
+    markType: str | None = None
+    timeZone: int | None = None
+    uses_avg: bool | None = None
+    uses_weighted_avg: bool | None = None
+    id: int | None = None
+    id_str: str | None = None
     name: str
     educationType: str
-    tsoCityId: int = None
-    tsoRegionTreePath: str = None
+    tsoCityId: int | None = None
+    tsoRegionTreePath: str | None = None
 
 class PersonSchool(Type):
     """[GET] /v2.0/schools/person-schools\n~~~\nСписок образовательных организаций пользователя\n~~~"""
